Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1378)

Unified Diff: include/v8-debug.h

Issue 19753: Changed the debugger API to allow only one debug event listener to be registe... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8-debug.h
===================================================================
--- include/v8-debug.h (revision 1198)
+++ include/v8-debug.h (working copy)
@@ -86,7 +86,7 @@
* (enum DebugEvent)
* \param exec_state execution state (JavaScript object)
* \param event_data event specific data (JavaScript object)
* \param data value passed by the user to AddDebugEventListener
*/
typedef void (*DebugEventCallback)(DebugEvent event,
Handle<Object> exec_state,
@@ -108,20 +108,14 @@
class EXPORT Debug {
public:
- // Add a C debug event listener.
- static bool AddDebugEventListener(DebugEventCallback that,
+ // Set a C debug event listener.
+ static bool SetDebugEventListener(DebugEventCallback that,
Handle<Value> data = Handle<Value>());
- // Add a JavaScript debug event listener.
- static bool AddDebugEventListener(v8::Handle<v8::Function> that,
+ // Set a JavaScript debug event listener.
+ static bool SetDebugEventListener(v8::Handle<v8::Object> that,
Handle<Value> data = Handle<Value>());
- // Remove a C debug event listener.
- static void RemoveDebugEventListener(DebugEventCallback that);
-
- // Remove a JavaScript debug event listener.
- static void RemoveDebugEventListener(v8::Handle<v8::Function> that);
-
// Break execution of JavaScript.
static void DebugBreak();
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
@@ -86,7 +86,7 @@
* \param exec_state execution state (JavaScript object)
* \param event_data event specific data (JavaScript object)
- * \param data value passed by the user to AddDebugEventListener
+ * \param data value passed by the user to SetDebugEventListener
*/
typedef void (*DebugEventCallback)(DebugEvent event,

Powered by Google App Engine
This is Rietveld 408576698